summaryrefslogtreecommitdiffstats
path: root/perl-install/install_steps_gtk.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/install_steps_gtk.pm')
-rw-r--r--perl-install/install_steps_gtk.pm25
1 files changed, 14 insertions, 11 deletions
diff --git a/perl-install/install_steps_gtk.pm b/perl-install/install_steps_gtk.pm
index 6c97db1f8..7ee2212c0 100644
--- a/perl-install/install_steps_gtk.pm
+++ b/perl-install/install_steps_gtk.pm
@@ -590,20 +590,23 @@ sub installPackages {
*install_any::changeMedium = sub {
my ($method, $medium) = @_;
- #- if not using a cdrom medium, always abort.
- if ($method eq 'cdrom' && !$::oem) {
- my $name = pkgs::mediumDescr($o->{packages}, $medium);
- local $| = 1; print "\a";
- my $time = time();
- my $r = $name !~ /commercial/i || ($o->{useless_thing_accepted2} ||= $o->ask_from_list_('', formatAlaTeX(install_messages::com_license()), [ N_("Accept"), N_("Refuse") ], "Accept") eq "Accept");
- $r &&= $o->ask_okcancel('', N("Change your Cd-Rom!
-
+ #- if not using a cdrom medium or an iso image, always abort.
+ return unless $method =~ /(^cdrom|-iso)$/ && !$::oem;
+
+ my $name = pkgs::mediumDescr($o->{packages}, $medium);
+ local $| = 1; print "\a";
+ my $time = time();
+ my $r = $name !~ /commercial/i || ($o->{useless_thing_accepted2} ||= $o->ask_from_list_('', formatAlaTeX(install_messages::com_license()), [ N_("Accept"), N_("Refuse") ], "Accept") eq "Accept");
+ if ($method =~ /-iso$/) {
+ $r = install_any::changeIso($name);
+ } else {
+ $r &&= $o->ask_okcancel('', N("Change your Cd-Rom!
Please insert the Cd-Rom labelled \"%s\" in your drive and press Ok when done.
If you don't have it, press Cancel to avoid installation from this Cd-Rom.", $name), 1);
- #- add the elapsed time (otherwise the predicted time will be rubbish)
- $start_time += time() - $time;
- return $r;
}
+ #- add the elapsed time (otherwise the predicted time will be rubbish)
+ $start_time += time() - $time;
+ return $r;
};
my $install_result;
catch_cdie { $install_result = $o->install_steps::installPackages($packages) }